==> viha-5.15.tar.gz: viha-5.15/tyotunnit.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

include "common.php";

function tulosta_tyoaika($hlo_id,$paivystys_id) {
  global $now;
  
  $ret = 0;
  
  $sql =
    "SELECT hlo_ajat_tyyppi_id,hlo_ajat_tyyppi,hlo_ajat.ts,variable_id
     FROM hlo_ajat,hlo_ajat_tyyppi
     WHERE hlo_id = $hlo_id
           AND hlo_ajat_tyyppi.id = hlo_ajat_tyyppi_id
           AND hlo_ajat_tyyppi_id < 3
           AND variable_id = " . s("paivystys") . "
     ORDER BY ts";
  $result = my_mysql_query($sql);
  if ($result) {
    $old = 0;
    $tuli = '';
    while ($a = mysql_fetch_array($result)) {
      echo "<TR><TD>",
	"<TD>$a[hlo_ajat_tyyppi]",
	"<TD>$a[ts]";
      $new = $a['hlo_ajat_tyyppi_id'];
      $v = $a['variable_id'];
      switch ($new) {
      case 1:
	if ($v == $paivystys_id) {
          # tuli. merkitse yls. l vlit jos perkkin useita samoja.
	  if ($old != 1) {
	    $tuli = $a['ts'];
	    $laskematta = true;
	  }
	} # oikea paivystys
	break;
      case 2:
	if ($v == $paivystys_id) {
          # lhti. laske aika ja tulosta. ellei tuloaikaa, ei voi laskea.
	  # jos useita lhti-tietueita perkkin, huomioi vain ensimminen.
	  if ($tuli != '') {
	    if ($laskematta) {
	      $lahti = $a['ts'];
	      $lahti_s = ota_yksi("SELECT UNIX_TIMESTAMP('$lahti')");
	      $tuli_s =  ota_yksi("SELECT UNIX_TIMESTAMP('$tuli')");
	      $oli_s = $lahti_s - $tuli_s;
	      if ($oli_s > 0) {
		$ret += $oli_s;
		$tulos = s_hhmmss($oli_s);
		echo "<TD>$tulos\n";
	      } else {
		echo "<TD>VIRHE?\n";
	      }
	      $laskematta = false;
	    } # laskematta
	  } # tuli != ''
	} # oikea paivystys
	break;
      } # switch
      $old = $new;
    } # while
    if (($old == 1) && ($tuli != '')) {
      echo "<TR><TD>",
	"<TD>Nyt",
	"<TD>$now";
      # tuli muttei ole viel lhtenyt. laske thn asti.
      $lahti = $now;
      $lahti_s = ota_yksi("SELECT UNIX_TIMESTAMP('$lahti')");
      $tuli_s =  ota_yksi("SELECT UNIX_TIMESTAMP('$tuli')");
      $oli_s = $lahti_s - $tuli_s;
      if ($oli_s > 0) {
	$ret += $oli_s;
	$tulos = s_hhmmss($oli_s);
	echo "<TD>$tulos\n";
      } else {
	echo "<TD>VIRHE?\n";
      }
    } # tullut muttei lhtenyt
  } # if result
  
  return $ret;
  
} # tulosta_tyoaika

$conf = get_nro_1('conf');
if ($conf == 0)
  $reuna = 0;
else
  $reuna = 1;

echo
"<html>
  <head>
   <title>ViHa - Tytunnit</title>
  </head> " . body_bgcolor() . "\n";

echo "<h1>" . ota_paivystys_nimi() . ", tytunnit</h1>";

if ($conf != 0) {
  taktiset_linkit();
 }

$kaikki = 0;
$n = 0;
$now = date('Y-m-d H:i:s');

# mennn henkilittin kaikki joilla on "sisn" - leimaus
$sql =
  "SELECT hlo.id,hlo.nimi,hlo_asema.pri,hlo_asema.hlo_asema
   FROM hlo,hlo_asema
   WHERE hlo.id IN (SELECT DISTINCT hlo_id
                    FROM hlo_ajat
                    WHERE hlo_ajat_tyyppi_id = 1
                          AND variable_id = " . s("paivystys") . ")
         AND hlo_asema.id = hlo.hlo_asema_id
   ORDER BY hlo.nimi";
$result = my_mysql_query($sql);
if ($result) {
  echo "<p><TABLE BORDER=\"$reuna\" cellpadding=\"2\">\n";
  echo tr_bgcolor()
    . "<TH>Nimi<TH>Tapahtuma<TH>Koska<TH>Tyaika\n";
  while ($a = mysql_fetch_array($result)) {
    $n ++;
    echo "<TR>",
      "<TD>$a[nimi]";
    $s = tulosta_tyoaika($a['id'], s('paivystys'));
    $kaikki += $s;
  }
  $yhteensa = s_hhmmss($kaikki);
  echo "<TR><TD>YHTEENS<TD>$n henkil<TD><TD>$yhteensa\n";
  echo "</TABLE>";
  
} else {
  echo "<P>Plop. Ei tytunteja.";
}

if ($conf != 0) {
  echo "<h2>Tulosteet</h2>\n";

  echo "<p><a href=\"tyotunnit.php?conf=0\">"
    . "Tulostettava versio</a>\n";

  loppu();
    
 }

?>
</body> 
</html>
<!-- RCS $Id: tyotunnit.php,v 1.13 2009/06/13 08:18:32 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/tyotunnit.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

include "common.php";

function tulosta_tyoaika($hlo_id,$paivystys_id) {
  global $now;
  
  $ret = 0;
  
  $sql =
    "SELECT hlo_ajat_tyyppi_id,hlo_ajat_tyyppi,hlo_ajat.ts,variable_id
     FROM hlo_ajat,hlo_ajat_tyyppi
     WHERE hlo_id = $hlo_id
           AND hlo_ajat_tyyppi.id = hlo_ajat_tyyppi_id
           AND hlo_ajat_tyyppi_id < 3
           AND variable_id = " . s("paivystys") . "
     ORDER BY ts";
  $result = my_mysql_query($sql);
  if ($result) {
    $old = 0;
    $tuli = '';
    while ($a = mysql_fetch_array($result)) {
      echo "<TR><TD>",
	"<TD>$a[hlo_ajat_tyyppi]",
	"<TD>$a[ts]";
      $new = $a['hlo_ajat_tyyppi_id'];
      $v = $a['variable_id'];
      switch ($new) {
      case 1:
	if ($v == $paivystys_id) {
          # tuli. merkitse yls. l vlit jos perkkin useita samoja.
	  if ($old != 1) {
	    $tuli = $a['ts'];
	    $laskematta = true;
	  }
	} # oikea paivystys
	break;
      case 2:
	if ($v == $paivystys_id) {
          # lhti. laske aika ja tulosta. ellei tuloaikaa, ei voi laskea.
	  # jos useita lhti-tietueita perkkin, huomioi vain ensimminen.
	  if ($tuli != '') {
	    if ($laskematta) {
	      $lahti = $a['ts'];
	      $lahti_s = ota_yksi("SELECT UNIX_TIMESTAMP('$lahti')");
	      $tuli_s =  ota_yksi("SELECT UNIX_TIMESTAMP('$tuli')");
	      $oli_s = $lahti_s - $tuli_s;
	      if ($oli_s > 0) {
		$ret += $oli_s;
		$tulos = s_hhmmss($oli_s);
		echo "<TD>$tulos\n";
	      } else {
		echo "<TD>VIRHE?\n";
	      }
	      $laskematta = false;
	    } # laskematta
	  } # tuli != ''
	} # oikea paivystys
	break;
      } # switch
      $old = $new;
    } # while
    if (($old == 1) && ($tuli != '')) {
      echo "<TR><TD>",
	"<TD>Nyt",
	"<TD>$now";
      # tuli muttei ole viel lhtenyt. laske thn asti.
      $lahti = $now;
      $lahti_s = ota_yksi("SELECT UNIX_TIMESTAMP('$lahti')");
      $tuli_s =  ota_yksi("SELECT UNIX_TIMESTAMP('$tuli')");
      $oli_s = $lahti_s - $tuli_s;
      if ($oli_s > 0) {
	$ret += $oli_s;
	$tulos = s_hhmmss($oli_s);
	echo "<TD>$tulos\n";
      } else {
	echo "<TD>VIRHE?\n";
      }
    } # tullut muttei lhtenyt
  } # if result
  
  return $ret;
  
} # tulosta_tyoaika

$conf = get_nro_1('conf');
if ($conf == 0)
  $reuna = 0;
else
  $reuna = 1;

echo
"<html>
  <head>
   <title>ViHa - Tytunnit</title>
  </head> " . body_bgcolor() . "\n";

echo "<h1>" . muotoile_operaatio() . ", tytunnit</h1>";

if ($conf != 0) {
  taktiset_linkit();
 }

$kaikki = 0;
$n = 0;
$now = date('Y-m-d H:i:s');

# mennn henkilittin kaikki joilla on "sisn" - leimaus
$sql =
  "SELECT hlo.id,hlo.nimi,hlo_asema.pri,hlo_asema.hlo_asema
   FROM hlo,hlo_asema
   WHERE hlo.id IN (SELECT DISTINCT hlo_id
                    FROM hlo_ajat
                    WHERE hlo_ajat_tyyppi_id = 1
                          AND variable_id = " . s("paivystys") . ")
         AND hlo_asema.id = hlo.hlo_asema_id
   ORDER BY hlo.nimi";
$result = my_mysql_query($sql);
if ($result) {
  echo "<p><TABLE BORDER=\"$reuna\" cellpadding=\"2\">\n";
  echo tr_vaalsin()
    . "<TH>Nimi<TH>Tapahtuma<TH>Koska<TH>Tyaika\n";
  while ($a = mysql_fetch_array($result)) {
    $n ++;
    echo "<TR>",
      "<TD>$a[nimi]";
    $s = tulosta_tyoaika($a['id'], s('paivystys'));
    $kaikki += $s;
  }
  $yhteensa = s_hhmmss($kaikki);
  echo "<TR><TD>YHTEENS<TD>$n henkil<TD><TD>$yhteensa\n";
  echo "</TABLE>";
  
} else {
  echo "<P>Plop. Ei tytunteja.";
}

if ($conf != 0) {
  echo "<h2>Tulosteet</h2>\n";

  echo "<p><a href=\"tyotunnit.php?conf=0\">"
    . "Tulostettava versio</a>\n";

  loppu();
    
 }

?>
</body> 
</html>
<!-- RCS $Id: tyotunnit.php,v 1.15 2009/09/29 16:09:15 riku Exp $ -->
